@@ -154,6 +154,9 @@ class SQLServerDataSource(DataSource):
     def literal_date(self, dt: datetime):
         return f"'{dt.strftime('%Y-%m-%d')}'"
 
+    def expr_count(self, expr):
+        return f"COUNT_BIG({expr})"
+
     def expr_length(self, expr):
         return f"LEN({expr})"
 
@@ -276,7 +279,10 @@ class SQLServerDataSource(DataSource):
         limit_sql = ""
         if limit is not None:
             limit_sql = f" \n TOP {limit} \n"
-        sql = f"SELECT {limit_sql} * FROM {qualified_table_name}{filter_sql}"
+
+        columns_names = ", ".join(self.sql_select_all_column_names(table_name))
+
+        sql = f"SELECT {limit_sql} {columns_names} FROM {qualified_table_name}{filter_sql}"
         return sql
 
     def sql_select_column_with_filter_and_limit(
@@ -302,7 +308,7 @@ class SQLServerDataSource(DataSource):
               FROM {table_name}
               WHERE {filter}
               GROUP BY {column_names})
-            SELECT {limit_sql} *
+            SELECT {limit_sql} {column_names}, frequency
             FROM frequencies
             WHERE frequency > 1"""
 
